Address review comments
diff --git a/lib/src/web_driver.dart b/lib/src/web_driver.dart
index f5e7349..9856950 100644
--- a/lib/src/web_driver.dart
+++ b/lib/src/web_driver.dart
@@ -140,17 +140,23 @@
 
   Mouse get mouse => new Mouse._(this);
 
   /// Take a screenshot of the current page as PNG.
   Future<String> captureScreenshotAsBase64() async =>
       await getRequest('screenshot');
 
   /// Take a screenshot of the current page as PNG.
   Future<List<int>> captureScreenshotAsList() async {
     var base64Encoded = captureScreenshotAsBase64();
     return BASE64.decode(await base64Encoded);
   }
-  /// Take a screenshot of the current page as PNG.
 
+  /// Take a screenshot of the current page as PNG as stream of uint8.
+  ///
+  /// Don't use this method. Prefer [captureScreenshotAsBase64] or
+  /// [captureScreenshotAsList]. Returning the data as Stream<int> can be very
+  /// slow.
+  @Deprecated('Use captureScreenshotAsBase64 or captureScreenshotAsList!')
   Stream<int> captureScreenshot() async* {
     yield* new Stream.fromIterable(await captureScreenshotAsList());
   }
@@ -140,17 +140,23 @@
   Mouse get mouse => new Mouse._(this);
 
-  /// Take a screenshot of the current page as PNG.
+  /// Take a screenshot of the current page as PNG and return it as
+  /// base64-encoded string.
   Future<String> captureScreenshotAsBase64() async =>
       await getRequest('screenshot');
@@ -140,17 +140,23 @@
       await getRequest('screenshot');
 
-  /// Take a screenshot of the current page as PNG.
+  /// Take a screenshot of the current page as PNG as list of uint8.
   Future<List<int>> captureScreenshotAsList() async {
     var base64Encoded = captureScreenshotAsBase64();